==> haskell-wai-handler-launch-3.0.3.1-800-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-EshcZSPfs1r4D4IvMn3NJM
key:                  wai-handler-launch-3.0.3.1-EshcZSPfs1r4D4IvMn3NJM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  3a095b279c4cb976691190cfe7aafe55
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-EshcZSPfs1r4D4IvMn3NJM
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    process-1.6.19.0 streaming-commons-0.2.3.1-JQd7Uft3nuo1D7ll7sM2yO
    transformers-0.6.1.0 wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
    warp-3.4.0-HpC7vpiyF2eriPYOziTRJ

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-802-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-BTo9YWlJbOYI3up6MSkXvf
key:                  wai-handler-launch-3.0.3.1-BTo9YWlJbOYI3up6MSkXvf
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  e4d1f4f0917ce0432c2c49ced69d8ebd
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-BTo9YWlJbOYI3up6MSkXvf
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    process-1.6.19.0 streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5
    transformers-0.6.1.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
